/*****************************************************************************
* Copyright (c) Future Technology Devices International 2014
* propriety of Future Technology devices International.
*
* Software License Agreement
*
* This code is provided as an example only and is not guaranteed by FTDI. 
* FTDI accept no responsibility for any issues resulting from its use. 
* The developer of the final application incorporating any parts of this 
* sample project is responsible for ensuring its safe and correct operation 
* and for any consequences resulting from its use.
*****************************************************************************/
/**
* @file                           Sender_Enhanced_SW_Flow_Ctl_2.ino
* @brief                          Sketch to demonstrate enhanced software flow control functionality for VI800A-TTLU add-on module.
								  Tested platform version: Arduino 1.0.4 and later
* @version                        1.0.0
* @date                           2014/10/01
*
*/



/* Arduino standard includes */
#include "SPI.h"
#include "Wire.h"


#include "FT_VI800A_TTLU.h"

FT_VI800A VI800A;

void setup()
{
	/* Initialize serial print related functionality */
	Serial.begin(9600);
    Serial.println("\n\r\n\r-----------Sender_Enhanced_SW_Flow_Ctl_2.ino--------------");
	
	VI800A.Init(FT_TTLU_CS);
		
	//the receiver will compare xon1 and xon2 for resume data transmission, and use xoff1 and xoff2 for halt data transmission. number 1 as the xon special character and number 2 as the xoff special character.  The receiver uses no FIFO trigger levels. 	
	VI800A.SetFlowControl(FT_VI800A_SW_Flow,FT_VI800A_NO_TX_FLOW_RX_XON1_XON2_XOFF1_XOFF2,48,48,49,49, FT_VI800A_Use_No_RX_Trigger);
	
	//enable receive FIFO
	VI800A.EnableFIFO(FT_VI800A_Enable);
	VI800A.clearFIFO();
}

char value[] = {'A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z'};
uint8_t valueIndex=0;
uint8_t command, manualStart=0,fifoStatus,incomingData, readData=1, numOfData=0;

//check the FIFO for errors in whole FIFO or the top of the FIFO
void GetFIOFStatus(){
	fifoStatus = VI800A.GetReceiveFIFOStatus();
	if(fifoStatus==FT_VI800A_FIFO_OK){
		return;
	}
	else{
		if((fifoStatus&FT_VI800A_Overrun_Error)==FT_VI800A_Overrun_Error)  //overflow condition
			Serial.println("Data Overflow occurred.");
		if((fifoStatus&FT_VI800A_Parity_Error)==FT_VI800A_Parity_Error) //for the next character to be read
			Serial.println("Data Parity Error occurred.");
		if((fifoStatus&FT_VI800A_Framing_Error)==FT_VI800A_Framing_Error) //for the next character to be read
			Serial.println("Data Framing Error occurred.");
		if((fifoStatus&FT_VI800A_Break_Interrupt)==FT_VI800A_Break_Interrupt) //for the next character to be read
			Serial.println("Line Break detected.");
	}
}

void loop()
{
   if(Serial.available() > 0)
   {
		command = Serial.read(); 
		if(command == 'p')
		{
			manualStart ^= 1;
			if(manualStart)
				Serial.println("Start to send data.");
			else	
				Serial.println("Halt data transmission.");
		}
		else if(command == 'q'){ //stack up data or enable FIFO
			readData^=1;
			if(readData){
				Serial.println("Read data from FIFO.");
				VI800A.EnableFIFO(FT_VI800A_Enable);
				VI800A.clearFIFO();
			}
			else{
				Serial.println("Stack data in FIFO");
				VI800A.EnableFIFO(FT_VI800A_Disable);
				VI800A.clearFIFO();
			}
		}
   }
   

   //check to see if there is any data in the receiver FIFO.
   if(VI800A.isDataInReceiver()){
		
		GetFIOFStatus();
		if(readData){
			incomingData = VI800A.Read();
			Serial.print("Received: ");
			Serial.println(incomingData);
		}
   }
	
	//push data to the transmit FIFO till it's full
	if(VI800A.GetTransmitFIFOFreeSpace() && manualStart){
		Serial.print("Sent: ");
		Serial.println(value[valueIndex]);
		VI800A.Write(value[valueIndex]);
		valueIndex=(valueIndex+1)%26;
	}
}


































