/*****************************************************************************
* Copyright (c) Future Technology Devices International 2014
* propriety of Future Technology devices International.
*
* Software License Agreement
*
* This code is provided as an example only and is not guaranteed by FTDI. 
* FTDI accept no responsibility for any issues resulting from its use. 
* The developer of the final application incorporating any parts of this 
* sample project is responsible for ensuring its safe and correct operation 
* and for any consequences resulting from its use.
*****************************************************************************/
/**
* @file                           Sender_SW_Flow_Ctl.ino
* @brief                          Sketch to demonstrate application software flow control for VI800A-TTLU add-on module.
								  Tested platform version: Arduino 1.0.4 and later
* @version                        1.0.0
* @date                           2014/10/01
*
*/


/* Arduino standard includes */
#include "SPI.h"
#include "Wire.h"


#include "FT_VI800A_TTLU.h"

FT_VI800A VI800A;

void setup()
{	
	/* Initialize serial print related functionality */
	Serial.begin(9600);
    Serial.println("\n\r\n\r-----------Sender_SW_Flow_Ctl.ino--------------");
	
	//set data format, same as calling VI800A.Ini(FT_TTLU_CS);
	VI800A.Init(FT_TTLU_CS,9600,FT_VI800A_No_Parity, FT_VI800A_One_Stop_Bit, FT_VI800A_Eight_Data_Bits);

	//use hardware flow control but no FIFO trigger
	VI800A.SetFlowControl(FT_VI800A_No_Flow);
	VI800A.EnableFIFO(FT_VI800A_Enable);
	VI800A.SetIOPinDirection(0xF0);
	VI800A.SetIOPinState(0xFF);
}

char value[] = {'A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z'};
uint8_t IOPinStates[] = {0xEF,0xDF,0xBf,0x7F};
char incomingData, XON=0x01,XOFF=0x02;
uint8_t valueIndex=0,IOPinStatesIndex=0, transmitData=0;
uint8_t command;

void loop()
{

   if(Serial.available() > 0)
   {
		command = Serial.read();
		if(command == 'p')
		{
			transmitData=1;
			Serial.println("Sending data to receiver.");
			delay(2000);
		}
		else{
			VI800A.Write(command);
		}
   }
   
	if(VI800A.isDataInReceiver()){
		incomingData = VI800A.Read();
		if(incomingData==XON){  //signal for data transmission
			transmitData=1;
			VI800A.SetIOPinState(IOPinStates[IOPinStatesIndex]);  //enable the next LED in the sequence
			IOPinStatesIndex=(IOPinStatesIndex+1)&0x03;
		}
		else if(incomingData==XOFF) //signal to halt data transmission
			transmitData=0;
		else{
			Serial.print("Received: ");
			Serial.println(incomingData);
		}
	}
   
   //send data to the receiver if there is enough data in the transmit FIFO
   if(transmitData && VI800A.GetTransmitFIFOFreeSpace()){
		VI800A.Write(value[valueIndex]);
		Serial.print("Sent: ");
		Serial.println(value[valueIndex]);
		valueIndex=(valueIndex+1)%26;
		delay(20);
   }
}





















































